GoogleAuthUrlParameters class

Constructors

GoogleAuthUrlParameters({required String clientId, required String redirectUri, required String responseType, required List<String> scopes, required String codeChallenge, required String codeChallengeMethod, required String state, String? loginHint})
const

Properties

clientId String
final
codeChallenge String
final
codeChallengeMethod String
final
hashCode int
The hash code for this object.
no setterinherited
loginHint String?
final
redirectUri String
final
responseType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes List<String>
final
state String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited