GoogleTokenExchanger class
This class exchange google authorization code for accessToken
- This send request to authorization's server in this endpoint https://oauth2.googleapis.com/token with these parameters
1- code (authorization code) that returns after user consents to application
2- client_id this is from google cloud console from web client
3- client_secret this is from google cloud console from web client
4- redirect_uri that detemine how google authorization server sends the response to your app , you must pass uri match with uri in authorized url in google cloud console in web client
5- code_verfier that you generate it first you sent it to compare it with code callange
6- grant_type that value must be "authorization_code"
and finally extract access token from response
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
exchangeCode(
GoogleTokenExchangerInputModel googleTokenExchangerInputModel) → Future< Either< GoogleAuthFailure, GoogleTokens> > - exchange authorization code for access token